@@ -190,7 +190,8 @@ hash_opts = [
                       'Setting this to more than one will cause additional '
                       'conductor services to prepare deployment environments '
                       'and potentially allow the Ironic cluster to recover '
-                      'more quickly if a conductor instance is terminated.')),
+                      'more quickly if a conductor instance is terminated.'),
+               deprecated_for_removal=True),
     cfg.IntOpt('hash_ring_reset_interval',
                default=15,
                help=_('Time (in seconds) after which the hash ring is '
@@ -210,6 +211,10 @@ image_opts = [
                default=os.path.join('$pybasedir',
                                     'common/isolinux_config.template'),
                help=_('Template file for isolinux configuration file.')),
+    cfg.StrOpt('grub_config_path',
+               default='/boot/grub/grub.cfg',
+               help=_('GRUB2 configuration file location on the UEFI ISO '
+                      'images produced by ironic.')),
     cfg.StrOpt('grub_config_template',
                default=os.path.join('$pybasedir',
                                     'common/grub_conf.template'),
@@ -220,6 +225,18 @@ image_opts = [
                       'looked for in '
                       '"/usr/lib/syslinux/modules/bios/ldlinux.c32" and '
                       '"/usr/share/syslinux/ldlinux.c32".')),
+    cfg.StrOpt('esp_image',
+               help=_('Path to EFI System Partition image file. This file is '
+                      'recommended for creating UEFI bootable ISO images '
+                      'efficiently. ESP image should contain a '
+                      'FAT12/16/32-formatted file system holding EFI boot '
+                      'loaders (e.g. GRUB2) for each hardware architecture '
+                      'ironic needs to boot. This option is only used when '
+                      'neither ESP nor ISO deploy image is configured to '
+                      'the node being deployed in which case ironic will '
+                      'attempt to fetch ESP image from the configured '
+                      'location or extract ESP image from UEFI-bootable '
+                      'deploy ISO image.')),
 ]
 
 img_cache_opts = [
@@ -238,10 +255,11 @@ netconf_opts = [
                       '"127.0.0.1".')),
 ]
 
-# NOTE(mariojv) By default, accessing this option when it's unset will return
-# None, indicating no notifications will be sent. oslo.config returns None by
-# default for options without set defaults that aren't required.
 notification_opts = [
+    # NOTE(mariojv) By default, accessing this option when it's unset will
+    # return None, indicating no notifications will be sent. oslo.config
+    # returns None by default for options without set defaults that aren't
+    # required.
     cfg.StrOpt('notification_level',
                choices=[('debug', _('"debug" level')),
                         ('info', _('"info" level')),
@@ -250,7 +268,22 @@ notification_opts = [
                         ('critical', _('"critical" level'))],
                help=_('Specifies the minimum level for which to send '
                       'notifications. If not set, no notifications will '
-                      'be sent. The default is for this option to be unset.'))
+                      'be sent. The default is for this option to be unset.')),
+    cfg.ListOpt(
+        'versioned_notifications_topics',
+        default=['ironic_versioned_notifications'],
+        help=_("""
+Specifies the topics for the versioned notifications issued by Ironic.
+
+The default value is fine for most deployments and rarely needs to be changed.
+However, if you have a third-party service that consumes versioned
+notifications, it might be worth getting a topic for that service.
+Ironic will send a message containing a versioned notification payload to each
+topic queue in this list.
+
+The list of versioned notifications is visible in
+https://docs.openstack.org/ironic/latest/admin/notifications.html
+""")),
 ]
 
 path_opts = [
@@ -299,6 +332,12 @@ service_opts = [
                       'When doing a rolling upgrade from version N to version '
                       'N+1, set (to pin) this to N. To unpin (default), leave '
                       'it unset and the latest versions will be used.')),
+    cfg.StrOpt('rpc_transport',
+               default='oslo',
+               choices=[('oslo', _('use oslo.messaging transport')),
+                        ('json-rpc', _('use JSON RPC transport'))],
+               help=_('Which RPC transport implementation to use between '
+                      'conductor and API services')),
 ]
 
 utils_opts = [
