@@ -144,7 +144,8 @@ class DbNodeTestCase(base.DbTestCase):
             uuid=uuidutils.generate_uuid(),
             maintenance=True,
             fault='boom',
-            resource_class='foo')
+            resource_class='foo',
+            conductor_group='group1')
         node3 = utils.create_test_node(
             driver='driver-one',
             uuid=uuidutils.generate_uuid(),
@@ -187,6 +188,14 @@ class DbNodeTestCase(base.DbTestCase):
         res = self.dbapi.get_nodeinfo_list(filters={'resource_class': 'foo'})
         self.assertEqual([node2.id], [r.id for r in res])
 
+        res = self.dbapi.get_nodeinfo_list(
+            filters={'conductor_group': 'group1'})
+        self.assertEqual([node2.id], [r.id for r in res])
+
+        res = self.dbapi.get_nodeinfo_list(
+            filters={'conductor_group': 'group2'})
+        self.assertEqual([], [r.id for r in res])
+
         res = self.dbapi.get_nodeinfo_list(
             filters={'reserved_by_any_of': ['fake-host',
                                             'another-fake-host']})
@@ -264,6 +273,19 @@ class DbNodeTestCase(base.DbTestCase):
                                                     states.INSPECTING})
         self.assertEqual([node2.id], [r[0] for r in res])
 
+    def test_get_nodeinfo_list_description(self):
+        node1 = utils.create_test_node(uuid=uuidutils.generate_uuid(),
+                                       description='Hello')
+        node2 = utils.create_test_node(uuid=uuidutils.generate_uuid(),
+                                       description='World!')
+        res = self.dbapi.get_nodeinfo_list(
+            filters={'description_contains': 'Hello'})
+        self.assertEqual([node1.id], [r[0] for r in res])
+
+        res = self.dbapi.get_nodeinfo_list(filters={'description_contains':
+                                                    'World!'})
+        self.assertEqual([node2.id], [r[0] for r in res])
+
     def test_get_node_list(self):
         uuids = []
         for i in range(1, 6):
@@ -292,7 +314,9 @@ class DbNodeTestCase(base.DbTestCase):
             chassis_id=ch2['id'],
             maintenance=True,
             fault='boom',
-            resource_class='foo')
+            resource_class='foo',
+            conductor_group='group1',
+            power_state='power on')
 
         res = self.dbapi.get_node_list(filters={'chassis_uuid': ch1['uuid']})
         self.assertEqual([node1.id], [r.id for r in res])
@@ -333,12 +357,30 @@ class DbNodeTestCase(base.DbTestCase):
         res = self.dbapi.get_node_list(filters={'resource_class': 'foo'})
         self.assertEqual([node2.id], [r.id for r in res])
 
+        res = self.dbapi.get_node_list(filters={'conductor_group': 'group1'})
+        self.assertEqual([node2.id], [r.id for r in res])
+
+        res = self.dbapi.get_node_list(filters={'conductor_group': 'group2'})
+        self.assertEqual([], [r.id for r in res])
+
         res = self.dbapi.get_node_list(filters={'id': node1.id})
         self.assertEqual([node1.id], [r.id for r in res])
 
         res = self.dbapi.get_node_list(filters={'uuid': node1.uuid})
         self.assertEqual([node1.id], [r.id for r in res])
 
+        uuids = [uuidutils.generate_uuid(),
+                 node1.uuid,
+                 uuidutils.generate_uuid()]
+        res = self.dbapi.get_node_list(filters={'uuid_in': uuids})
+        self.assertEqual([node1.id], [r.id for r in res])
+
+        res = self.dbapi.get_node_list(filters={'with_power_state': True})
+        self.assertEqual([node2.id], [r.id for r in res])
+
+        res = self.dbapi.get_node_list(filters={'with_power_state': False})
+        self.assertEqual([node1.id], [r.id for r in res])
+
         # ensure unknown filters explode
         filters = {'bad_filter': 'foo'}
         self.assertRaisesRegex(ValueError,
@@ -353,6 +395,19 @@ class DbNodeTestCase(base.DbTestCase):
                                self.dbapi.get_node_list,
                                filters=filters)
 
+    def test_get_node_list_description(self):
+        node1 = utils.create_test_node(uuid=uuidutils.generate_uuid(),
+                                       description='Hello')
+        node2 = utils.create_test_node(uuid=uuidutils.generate_uuid(),
+                                       description='World!')
+        res = self.dbapi.get_node_list(filters={
+            'description_contains': 'Hello'})
+        self.assertEqual([node1.id], [r.id for r in res])
+
+        res = self.dbapi.get_node_list(filters={
+            'description_contains': 'World!'})
+        self.assertEqual([node2.id], [r.id for r in res])
+
     def test_get_node_list_chassis_not_found(self):
         self.assertRaises(exception.ChassisNotFound,
                           self.dbapi.get_node_list,
@@ -503,6 +558,15 @@ class DbNodeTestCase(base.DbTestCase):
         self.assertRaises(exception.NodeNotFound,
                           self.dbapi.node_trait_exists, node.id, trait.trait)
 
+    def test_allocations_get_destroyed_after_destroying_a_node_by_uuid(self):
+        node = utils.create_test_node()
+
+        allocation = utils.create_test_allocation(node_id=node.id)
+
+        self.dbapi.destroy_node(node.uuid)
+        self.assertRaises(exception.AllocationNotFound,
+                          self.dbapi.get_allocation_by_id, allocation.id)
+
     def test_update_node(self):
         node = utils.create_test_node()
 
@@ -789,3 +853,38 @@ class DbNodeTestCase(base.DbTestCase):
                                'Multiple nodes',
                                self.dbapi.get_node_by_port_addresses,
                                addresses)
+
+    def test_check_node_list(self):
+        node1 = utils.create_test_node(uuid=uuidutils.generate_uuid())
+        node2 = utils.create_test_node(uuid=uuidutils.generate_uuid(),
+                                       name='node_2')
+        node3 = utils.create_test_node(uuid=uuidutils.generate_uuid(),
+                                       name='node_3')
+
+        mapping = self.dbapi.check_node_list([node1.uuid, node2.name,
+                                              node3.uuid])
+        self.assertEqual({node1.uuid: node1.uuid,
+                          node2.name: node2.uuid,
+                          node3.uuid: node3.uuid},
+                         mapping)
+
+    def test_check_node_list_non_existing(self):
+        node1 = utils.create_test_node(uuid=uuidutils.generate_uuid())
+        node2 = utils.create_test_node(uuid=uuidutils.generate_uuid(),
+                                       name='node_2')
+        uuid = uuidutils.generate_uuid()
+
+        exc = self.assertRaises(exception.NodeNotFound,
+                                self.dbapi.check_node_list,
+                                [node1.uuid, uuid, 'could-be-a-name',
+                                 node2.name])
+        self.assertIn(uuid, str(exc))
+        self.assertIn('could-be-a-name', str(exc))
+
+    def test_check_node_list_impossible(self):
+        node1 = utils.create_test_node(uuid=uuidutils.generate_uuid())
+
+        exc = self.assertRaises(exception.NodeNotFound,
+                                self.dbapi.check_node_list,
+                                [node1.uuid, 'this/cannot/be/a/name'])
+        self.assertIn('this/cannot/be/a/name', str(exc))
