@@ -233,7 +233,8 @@ class iPXEBootTestCase(db_base.DbTestCase):
                               ipxe_use_swift=False,
                               whole_disk_image=False,
                               mode='deploy',
-                              node_boot_mode=None):
+                              node_boot_mode=None,
+                              persistent=False):
         mock_build_pxe.return_value = {}
         kernel_label = '%s_kernel' % mode
         ramdisk_label = '%s_ramdisk' % mode
@@ -260,13 +261,14 @@ class iPXEBootTestCase(db_base.DbTestCase):
             dhcp_opts = pxe_utils.dhcp_options_for_instance(
                 task, ipxe_enabled=True)
             task.driver.boot.prepare_ramdisk(task, {'foo': 'bar'})
-            mock_deploy_img_info.assert_called_once_with(task.node, mode=mode)
+            mock_deploy_img_info.assert_called_once_with(task.node, mode=mode,
+                                                         ipxe_enabled=True)
             provider_mock.update_dhcp.assert_called_once_with(task, dhcp_opts)
             if self.node.provision_state == states.DEPLOYING:
                 get_boot_mode_mock.assert_called_once_with(task)
             set_boot_device_mock.assert_called_once_with(task,
                                                          boot_devices.PXE,
-                                                         persistent=False)
+                                                         persistent=persistent)
             if ipxe_use_swift:
                 if whole_disk_image:
                     self.assertFalse(mock_cache_r_k.called)
@@ -306,6 +308,80 @@ class iPXEBootTestCase(db_base.DbTestCase):
         self.node.save()
         self._test_prepare_ramdisk()
 
+    def test_prepare_ramdisk_force_persistent_boot_device_true(self):
+        self.node.provision_state = states.DEPLOYING
+        driver_info = self.node.driver_info
+        driver_info['force_persistent_boot_device'] = 'True'
+        self.node.driver_info = driver_info
+        self.node.save()
+        self._test_prepare_ramdisk(persistent=True)
+
+    def test_prepare_ramdisk_force_persistent_boot_device_bool_true(self):
+        self.node.provision_state = states.DEPLOYING
+        driver_info = self.node.driver_info
+        driver_info['force_persistent_boot_device'] = True
+        self.node.driver_info = driver_info
+        self.node.save()
+        self._test_prepare_ramdisk(persistent=True)
+
+    def test_prepare_ramdisk_force_persistent_boot_device_sloppy_true(self):
+        for value in ['true', 't', '1', 'on', 'y', 'YES']:
+            self.node.provision_state = states.DEPLOYING
+            driver_info = self.node.driver_info
+            driver_info['force_persistent_boot_device'] = value
+            self.node.driver_info = driver_info
+            self.node.save()
+            self._test_prepare_ramdisk(persistent=True)
+
+    def test_prepare_ramdisk_force_persistent_boot_device_false(self):
+        self.node.provision_state = states.DEPLOYING
+        driver_info = self.node.driver_info
+        driver_info['force_persistent_boot_device'] = 'False'
+        self.node.driver_info = driver_info
+        self.node.save()
+        self._test_prepare_ramdisk()
+
+    def test_prepare_ramdisk_force_persistent_boot_device_bool_false(self):
+        self.node.provision_state = states.DEPLOYING
+        driver_info = self.node.driver_info
+        driver_info['force_persistent_boot_device'] = False
+        self.node.driver_info = driver_info
+        self.node.save()
+        self._test_prepare_ramdisk(persistent=False)
+
+    def test_prepare_ramdisk_force_persistent_boot_device_sloppy_false(self):
+        for value in ['false', 'f', '0', 'off', 'n', 'NO', 'yxz']:
+            self.node.provision_state = states.DEPLOYING
+            driver_info = self.node.driver_info
+            driver_info['force_persistent_boot_device'] = value
+            self.node.driver_info = driver_info
+            self.node.save()
+            self._test_prepare_ramdisk()
+
+    def test_prepare_ramdisk_force_persistent_boot_device_default(self):
+        self.node.provision_state = states.DEPLOYING
+        driver_info = self.node.driver_info
+        driver_info['force_persistent_boot_device'] = 'Default'
+        self.node.driver_info = driver_info
+        self.node.save()
+        self._test_prepare_ramdisk(persistent=False)
+
+    def test_prepare_ramdisk_force_persistent_boot_device_always(self):
+        self.node.provision_state = states.DEPLOYING
+        driver_info = self.node.driver_info
+        driver_info['force_persistent_boot_device'] = 'Always'
+        self.node.driver_info = driver_info
+        self.node.save()
+        self._test_prepare_ramdisk(persistent=True)
+
+    def test_prepare_ramdisk_force_persistent_boot_device_never(self):
+        self.node.provision_state = states.DEPLOYING
+        driver_info = self.node.driver_info
+        driver_info['force_persistent_boot_device'] = 'Never'
+        self.node.driver_info = driver_info
+        self.node.save()
+        self._test_prepare_ramdisk(persistent=False)
+
     def test_prepare_ramdisk_rescue(self):
         self.node.provision_state = states.RESCUING
         self.node.save()
@@ -516,8 +592,10 @@ class iPXEBootTestCase(db_base.DbTestCase):
                           ramdisk_label: ['', '/path/to/' + ramdisk_label]}
             get_image_info_mock.return_value = image_info
             task.driver.boot.clean_up_ramdisk(task)
-            clean_up_pxe_env_mock.assert_called_once_with(task, image_info)
-            get_image_info_mock.assert_called_once_with(task.node, mode=mode)
+            clean_up_pxe_env_mock.assert_called_once_with(
+                task, image_info, ipxe_enabled=True)
+            get_image_info_mock.assert_called_once_with(
+                task.node, mode=mode, ipxe_enabled=True)
 
     def test_clean_up_ramdisk(self):
         self.node.provision_state = states.DEPLOYING
@@ -736,25 +814,6 @@ class iPXEBootTestCase(db_base.DbTestCase):
                                                          boot_devices.DISK,
                                                          persistent=True)
 
-    @mock.patch.object(manager_utils, 'node_set_boot_device', autospec=True)
-    @mock.patch.object(pxe_utils, 'clean_up_pxe_config', autospec=True)
-    def test_is_force_persistent_boot_device_enabled(
-            self, clean_up_pxe_config_mock, set_boot_device_mock):
-        with task_manager.acquire(self.context, self.node.uuid) as task:
-            instance_info = task.node.instance_info
-            instance_info['capabilities'] = {'boot_option': 'local'}
-            task.node.instance_info = instance_info
-            task.node.save()
-            task.driver.boot.prepare_instance(task)
-            clean_up_pxe_config_mock.assert_called_once_with(
-                task, ipxe_enabled=True)
-            driver_info = task.node.driver_info
-            driver_info['force_persistent _boot_device'] = True
-            task.node.driver_info = driver_info
-            set_boot_device_mock.assert_called_once_with(task,
-                                                         boot_devices.DISK,
-                                                         persistent=True)
-
     @mock.patch.object(manager_utils, 'node_set_boot_device', autospec=True)
     @mock.patch.object(pxe_utils, 'clean_up_pxe_config', autospec=True)
     def test_prepare_instance_localboot_active(self, clean_up_pxe_config_mock,
@@ -780,7 +839,8 @@ class iPXEBootTestCase(db_base.DbTestCase):
                           'ramdisk': ['', '/path/to/ramdisk']}
             get_image_info_mock.return_value = image_info
             task.driver.boot.clean_up_instance(task)
-            clean_up_pxe_env_mock.assert_called_once_with(task, image_info)
+            clean_up_pxe_env_mock.assert_called_once_with(
+                task, image_info, ipxe_enabled=True)
             get_image_info_mock.assert_called_once_with(
                 task, ipxe_enabled=True)
 
